/* ******************************************************************************************** */
/* *                                                                                          * */
/* *                              X.25 Interface Library                                      * */
/* *                              ----------------------                                      * */
/* *                                                                                          * */
/* *                              X25_Interface_Library.r                                     * */
/* *                                                                                          * */
/* *..........................................................................................* */
/* *                                                                                          * */
/* *     Resources that are used by the "X.25 Interface Library" set of Interface routines.   * */
/* *                                                                                          * */
/* *..........................................................................................* */
/* *                                                                                          * */
/* *     The symbolic definitions for resource numbers are defined in the file                * */
/* *     "X25_Interface_Library_defs.r".                                                      * */
/* *                                                                                          * */
/* *                                                                                          * */
/* *------------------------------------------------------------------------------------------* */
/* *                                                                                          * */
/* *                   Copyright  1988-1990 Apple Computer, Inc.                             * */
/* *                               All Rights Reserved                                        * */
/* *                                                                                          * */
/* *------------------------------------------------------------------------------------------* */
/* *                                                                                          * */
/* *     Revision History:                                                                    * */
/* *                                                                                          * */
/* *     Date       Individual          Changes                                               * */
/* *     .........  ................... ..................................................    * */
/* *                                                                                          * */
/* *     05 Oct 88  D. N. Willey        Original Version                                      * */
/* *                                                                                          * */
/* *        Oct 88  D. N. Willey        Continuing enhancements and additions                 * */
/* *          to                                                                              * */
/* *        Dec 88                                                                            * */
/* *                                                                                          * */
/* *     07 Dec 89  D. N. Willey        Split the resource symbolic definitions into a        * */
/* *                                    separate file.                                        * */
/* *                                                                                          * */
/* *     31 May 91  D. N. Willey        Corrected spelling errors in error messages.          * */
/* *                                                                                          * */
/* *                                                                                          * */
/* ******************************************************************************************** */
    

    

/* ******************************************************************************************** */
/* *                                                                                          * */
/* *    Common Include Files and Definitions                                                  * */
/* *                                                                                          * */
/* ******************************************************************************************** */

#ifndef     __include_files__

#define     __include_files__

#include    "Types.r"
#include    "SysTypes.r"

#endif      __include_files__

#include    "X25_Interface_Library_defs.r"


/* ******************************************************************************************** */
/* *                                                                                          * */
/* *    Handy Color Definitions                                                               * */
/* *                                                                                          * */
/* ******************************************************************************************** */

#define     color_black                 0x0000, 0x0000, 0x0000
#define     color_white                 0xFFFF, 0xFFFF, 0xFFFF
#define     color_gold                  0xFFFF, 0xCFFF, 0x1FFF

#define     color_saturated_red         0xFFFF, 0x0000, 0x0000
#define     color_saturated_blue        0x0000, 0x0000, 0xFFFF
#define     color_saturated_green       0x0000, 0xFFFF, 0x0000

#define     color_red                   0xFFFF, 0x0000, 0x0000
#define     color_dark_red              0x6666, 0x0000, 0x0000
#define     color_orange                0xFFFF, 0x3333, 0xAAAA
#define     color_green                 0x0000, 0xFFFF, 0x0000
#define     color_blue                  0x0000, 0x0000, 0xFFFF
#define     color_light_blue            0x4FFF, 0xBFFF, 0xFFFF
#define     color_pink                  0xFFFF, 0x8888, 0xAAAA
#define     color_purple                0xFFFF, 0x3FFF, 0xFFFF
#define     color_cyan                  0x0000, 0xAAAA, 0xAAAA
#define     color_gray_green            0xAAAA, 0xFFFF, 0xAAAA
#define     color_cream                 0xFFFF, 0xFFFF, 0xCCCC
#define     color_brown                 0x6666, 0x3333, 0x0000
#define     color_dark_brown            0x9900, 0x6600, 0x0000


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    "ictl" resources don't have a type def, therefore everything has to be put in as      + */
/* +    raw hex data.                                                                         + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

#define     ictb_color_black            $"0000    0000    0000"
#define     ictb_color_white            $"FFFF    FFFF    FFFF"

#define     ictb_color_light_blue       $"4FFF    BFFF    FFFF"


/* ******************************************************************************************** */
/* *                                                                                          * */
/* *    Resource Data                                                                         * */
/* *                                                                                          * */
/* ******************************************************************************************** */



/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    X.25 Server Icon (Worlds on a Plate) a used by the Finder                             + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'ICN#' ( 128 ) {   /* Worlds */
    { /* array: 2 elements */
        /* [1] */
        $"00 00 00 00 00 F8 0F 80 03 FE 31 E0 07 D7 4F F0"
        $"0F 83 BF F8 0B 01 FF F8 11 F6 F8 7C 11 F4 F1 FC"
        $"11 F8 D6 44 11 FC 6E 44 11 FC 7E 04 10 C4 7E 04"
        $"08 84 7C 08 08 C0 FC 08 04 F9 38 10 FF FF FF FF"
        $"40 00 00 02 3F FF FF FC 01 2A 05 00 00 AA 05 00"
        $"00 AB 05 00 00 65 DD 00 00 22 37 00 00 19 09 00"
        $"00 0C 05 00 00 03 03 00 00 00 C1 00 00 00 21 00"
        $"00 00 21 00 00 00 7F 80 00 00 7F 80 00 00 7F 80",
        /* [2] */
        $"00 F8 0F 80 03 FE 3F E0 07 FF 7F F0 0F FF FF F8"
        $"1F FF FF FC 1F FF FF FC 3F FF FF FE 3F FF FF FE"
        $"3F FF FF FE 3F FF FF FE 3F FF FF FE 3F FF FF FE"
        $"3F FF FF FC 1F FF FF FC 0F FF FF F8 FF FF FF FF"
        $"7F FF FF FE 3F FF FF FC 01 FE 07 00 00 FE 07 00"
        $"00 FF 07 00 00 7F EF 00 00 3F FF 00 00 1F FF 00"
        $"00 0F FF 00 00 03 FF 00 00 00 FF 00 00 00 3F 00"
        $"00 00 3E 00 00 00 7F 80 00 00 7F 80 00 00 7F 80"
    }
};


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    X.25 Server Icon (Storm Cloud) a used by the Finder  (Least we Forget)                + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'ICN#' ( 129 ) {       /* Storm cloud */
    { /* array: 2 elements */
        /* [1] */
        $"00 18 00 00 00 24 00 00 1C DC 0C 00 23 22 D3 00"
        $"40 13 30 88 4C 04 08 B6 32 C0 05 41 21 30 06 01"
        $"50 88 0A 01 20 08 10 0E 20 10 00 81 70 00 85 02"
        $"80 81 02 02 88 80 C2 04 89 00 35 88 76 88 C8 70"
        $"00 77 23 40 00 00 1C 80",
        /* [2] */
        $"00 18 00 00 00 3C 00 00 1C FC 0C 00 3F FE DF 00"
        $"7F FF FF 88 7F FF FF BE 3F FF FF FF 3F FF FF FF"
        $"7F FF FF FF 3F FF FF FE 3F FF FF FF 7F FF FF FE"
        $"FF FF FF FE FF FF FF FC FF FF FF F8 76 FF FF F0"
        $"09 77 3F C0 12 9E 1C 80 25 38 82 10 40 71 24 20"
        $"10 E0 41 40 25 F8 8A 00 09 32 10 20 12 64 22 40"
        $"04 C0 04 80 01 E4 89 00 10 C9 22 00 21 92 40 80"
        $"0B 24 01 00 16 00 00 00 24 00 00 00 08"
    }
};


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    X.25 Server Icon (Worlds on a Plate) used in many Dialogs                             + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    Note that this Icon is supplied in both a B/W (ICON) and Color (cicn) version         + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'ICON' ( 128 ) {
    $"00 00 00 00 00 F8 0F 80 03 FE 31 E0 07 D7 4F F0"
    $"0F 83 BF F8 0B 01 FF F8 11 F6 F8 7C 11 F4 F1 FC"
    $"11 F8 D6 44 11 FC 6E 44 11 FC 7E 04 10 C4 7E 04"
    $"08 84 7C 08 08 C0 FC 08 04 F9 38 10 FF FF FF FF"
    $"40 00 00 02 3F FF FF FC 01 2A 05 00 00 AA 05 00"
    $"00 AB 05 00 00 65 DD 00 00 22 37 00 00 19 09 00"
    $"00 0C 05 00 00 03 03 00 00 00 C1 00 00 00 21 00"
    $"00 00 21 00 00 00 7F 80 00 00 7F 80 00 00 7F 80"
    };

#ifdef DUMMY

resource 'cicn' ( 128, "cicn Save" ) {
    {0, 0, 32, 32},
    0,
    unpacked,
    0,
    0x480000,
    0x480000,
    chunky,
    4,
    1,
    4,
    0,
    0,
    4,
    {0, 0, 32, 32},
    4,
    {0, 0, 32, 32},
    $"00 00 00 00 00 F8 0F 80 03 FE 3F E0 07 FF 7F F0"
    $"0F FF FF F8 0F FF FF F8 1F FF FF FC 1F FF FF FC"
    $"1F FF FF FC 1F FF FF FC 1F FF FF FC 1F FF FF FC"
    $"0F FF FF F8 0F FF FF F8 07 FF FF F0 FF FF FF FF"
    $"7F FF FF FE 3F FF FF FC 01 FF FF 00 00 FF FF 00"
    $"00 FF FF 00 00 7F FF 00 00 3F FF 00 00 1F FF 00"
    $"00 0F FF 00 00 03 FF 00 00 00 FF 00 00 00 3F 00"
    $"00 00 3F 00 00 00 7F 80 00 00 7F 80 00 00 7F 80",
    $"00 00 00 00 00 F8 0F 80 03 FE 31 E0 07 D7 4F F0"
    $"0F 83 BF F8 0B 01 FF F8 11 F6 F8 7C 11 F4 F1 FC"
    $"11 F8 D6 44 11 FC 6E 44 11 FC 7E 04 10 C4 7E 04"
    $"08 84 7C 08 08 C0 FC 08 04 F9 38 10 FF FF FF FF"
    $"40 00 00 02 3F FF FF FC 01 2A 05 00 00 AA 05 00"
    $"00 AB 05 00 00 65 DD 00 00 22 37 00 00 19 09 00"
    $"00 0C 05 00 00 03 03 00 00 00 C1 00 00 00 21 00"
    $"00 00 21 00 00 00 7F 80 00 00 7F 80 00 00 7F 80",
    0x0,
    0,
    {   /* array ColorSpec: 11 elements */
        /* [1] */
        0, 65535, 65535, 65535,
        /* [2] */
        1, 44553, 65535, 64909,
        /* [3] */
        2, 0, 0, 65535,
        /* [4] */
        3, 0, 39935, 0,
        /* [5] */
        4, 0, 25575, 0,
        /* [6] */
        5, 56319, 52774, 54370,
        /* [7] */
        6, 25975, 24340, 25076,
        /* [8] */
        7, 64256, 57347, 38354,
        /* [9] */
        8, 34048, 30386, 20323,
        /* [10] */
        9, 65535, 0, 0,
        /* [11] */
        10, 0, 0, 0
    },
    $"00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00"
    $"00 00 00 00 44 44 40 00 00 00 22 24 40 00 00 00"
    $"00 00 00 44 33 33 34 40 00 22 11 13 34 40 00 00"
    $"00 00 04 33 33 13 13 34 02 11 33 33 33 34 00 00"
    $"00 00 43 33 31 11 11 33 43 33 33 33 33 33 40 00"
    $"00 00 21 33 11 11 11 13 43 33 33 33 33 33 40 00"
    $"00 02 11 13 33 33 13 31 12 33 31 11 13 33 34 00"
    $"00 02 11 13 33 33 13 11 12 33 11 13 33 33 34 00"
    $"00 02 11 13 33 33 31 11 12 13 13 31 13 11 12 00"
    $"00 02 11 13 33 33 33 11 12 31 33 31 13 11 12 00"
    $"00 02 11 13 33 33 33 11 12 33 33 31 11 11 12 00"
    $"00 02 11 11 33 11 13 11 12 33 33 31 11 11 12 00"
    $"00 00 21 11 31 11 13 11 23 33 33 11 11 11 20 00"
    $"00 00 21 11 33 11 11 11 23 33 33 11 11 11 20 00"
    $"00 00 02 11 33 33 31 12 11 33 31 11 11 12 00 00"
    $"66 66 66 66 66 66 66 66 66 66 66 66 66 66 66 66"
    $"06 55 55 55 55 55 55 55 55 55 55 55 55 55 55 60"
    $"00 66 66 66 66 66 66 66 66 66 66 66 66 66 66 00"
    $"00 00 00 08 77 87 87 80 00 00 08 78 00 00 00 00"
    $"00 00 00 00 87 87 87 80 00 00 08 78 00 00 00 00"
    $"00 00 00 00 87 87 87 88 00 00 08 78 00 00 00 00"
    $"00 00 00 00 08 87 78 78 88 08 88 78 00 00 00 00"
    $"00 00 00 00 00 87 77 87 77 88 78 88 00 00 00 00"
    $"00 00 00 00 00 08 87 78 77 77 87 78 00 00 00 00"
    $"00 00 00 00 00 00 88 77 77 77 78 78 00 00 00 00"
    $"00 00 00 00 00 00 00 88 77 77 77 88 00 00 00 00"
    $"00 00 00 00 00 00 00 00 88 77 77 78 00 00 00 00"
    $"00 00 00 00 00 00 00 00 00 87 77 78 00 00 00 00"
    $"00 00 00 00 00 00 00 00 00 87 77 78 00 00 00 00"
    $"00 00 00 00 00 00 00 00 0A AA AA AA A0 00 00 00"
    $"00 00 00 00 00 00 00 00 0A AA AA AA A0 00 00 00"
    $"00 00 00 00 00 00 00 00 0A AA AA AA A0 00 00 00"
};

#endif DUMMY




/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    X.25 Server Icon (Thunder Cloud) used in many Dialogs  (Least we Forget)              + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'ICON' ( 129 ) {
    $"00 18 00 00 00 24 00 00 1C DC 0C 00 23 22 D3 00"
    $"40 13 30 88 4C 04 08 B6 32 C0 05 41 21 30 06 01"
    $"50 88 0A 01 20 08 10 0E 20 10 00 81 70 00 85 02"
    $"80 81 02 02 88 80 C2 04 89 00 35 88 76 88 C8 70"
    $"00 77 23 40 00 00 1C 80"
    };


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    "X25_User_ID" Dialog Window - Name and Password Entry                                 + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    If "bounds_rectangle.left" is equal to zero, the DLOG will be aligned horizontally.   + */
/* +    If "bounds_rectangle.top"  is equal to zero, the DLOG will be aligned vertically.     + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'DLOG' ( dialog_get_name_pass, "X.25 Server" ) {       /* Dialog window                */
    { 0, 0, 240, 418 },                                             /* Bounds Rectangle         */
    dBoxProc,                                                       /* Window type              */
    invisible,                                                      /* Window visiable?         */
    nogoAway,                                                       /* go-away box?             */
    0,                                                              /* RefCon value             */
    dialog_get_name_pass,                                           /* DITL id                  */
    "X.25 Server"                                                   /* Window title             */
    };
    
resource 'dctb' ( dialog_get_name_pass ) {                      /* Dialog Color Table           */
    {                                                               /* (Reserved fields)        */
        wContentColor,      color_white;                            /* Content Color            */
        wFrameColor,        color_black;                            /* Frame Color              */
        wTextColor,         color_black;                            /* Text Color               */
        wHiliteColor,       $FFFF, $FFFF, $0000;                    /* Hilite Color     - N/A   */
        wTitleBarColor,     $4000, $4000, $FFFF                     /* Title Bar Color  - N/A   */
        }
    };

resource 'DITL' ( dialog_get_name_pass ) {                      /* DITL List                    */
    { /* array DITLarray: 13 elements */

        /* Item #1 ( OK_Button )                                                                */
        {192, 290, 212, 370},                                       /* Bounds Rectangle         */
        Button {                                                    /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "OK"                                                    /* Button Text              */
            },
        
        /* Item #2 ( Cancel_Button )                                                            */
        {192, 48, 212, 128},                                        /* Bounds Rectangle         */
        Button {                                                    /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "Cancel"                                                /* Button Text              */
            },
        
        /* Item #3 ( Password_Button )                                                          */
        {192, 149, 212, 269},                                       /* Bounds Rectangle         */
        Button {                                                    /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "Set Password"                                          /* Button Text              */
            },
        
        /* Item #4 ( X.25 Icon )                                                                */
        {10, 10, 42, 42},                                           /* Bounds Rectangle         */
        Icon {                                                      /* Type of item             */
            disabled,                                               /* Item enabled?            */
            128                                                     /* Icon Number              */
            },

        /* Item #5 ( Gateway "name" Message )                                                   */
        {28, 48, 60, 370},                                          /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "Connect to the X.25 Server \"^0\" as:"                 /* Static Text              */
            },

        /* Item #6 ( Guest Radio Button )                                                       */
        {72, 64, 88, 192},                                          /* Bounds Rectangle         */
        RadioButton {                                               /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "Guest"                                                 /* Button Text              */
            },

        /* Item #7 ( Registered-User Radio Button )                                             */
        {96, 64, 112, 192},                                         /* Bounds Rectangle         */
        RadioButton {                                               /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "Registered User"                                       /* Button Text              */
            },

        /* Item #8 ( "Name:" User Name Field Identifier )                                       */
        {128, 64, 144, 144},                                        /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "Name:"                                                 /* Static Text              */
            },

        /* Item #9 ( "Password:" User Password Field Identifier )                               */
        {152, 64, 168, 144},                                        /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "Password:"                                             /* Static Text              */
            },

        /* Item #10 ( User Name Input )                                                         */
        {128, 152, 144, 370},                                       /* Bounds Rectangle         */
        EditText {                                                  /* Type of item             */
            disabled,                                               /* Item enabled?            */
            ""                                                      /* Dynamic Text             */
            },

        /* Item #11 ( User Password Input )                                                     */
        {152, 152, 168, 216},                                       /* Bounds Rectangle         */
        EditText {                                                  /* Type of item             */
            enabled,                                                /* Item enabled?            */
            ""                                                      /* Dynamic Text             */
            },

        /* Item #12 ( "(Scrambled)" )                                                           */
        {152, 224, 168, 370},                                       /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "(Scrambled)"                                           /* Static Text              */
            },

        /* Item #13 ( "Version String" )                                                        */
        {224, 360, 238, 416},                                       /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            /*  $$Shell("Build_Version_short")  */                  /* Static Text              */
            ""                                                      /* Static Text              */
            }

        }
    };

data 'ictb' ( dialog_get_name_pass ) {                          /* DITL Color Table             */
        /* 00 */    $"0000 0000"                                    /* #01 - OK Button          */
        /* 04 */    $"0000 0000"                                    /* #02 - Cancel Button      */
        /* 08 */    $"0000 0000"                                    /* #03 - Pass Button        */
        /* 0C */    $"0000 0000"                                    /* #04 - X.25 Icon          */
        /* 10 */    $"500F 0054"                                    /* #05 - Gateway Name       */
        /* 14 */    $"0000 0000"                                    /* #06 - Guest Button       */
        /* 18 */    $"0000 0000"                                    /* #07 - Reg Button         */
        /* 1C */    $"500F 0054"                                    /* #08 - Name: Static Text  */
        /* 20 */    $"500F 0054"                                    /* #09 - Pass Static Text   */
        /* 24 */    $"D00F 0040"                                    /* #10 - Name Edit Text     */
        /* 28 */    $"D00F 0040"                                    /* #11 - Pass Edit Text     */
        /* 2C */    $"500F 0054"                                    /* #12 - Scramb Static Text */
        /* 30 */    $"500F 0068"                                    /* #13 - Version Static Text*/
        /* 34 */    $"0000 0000"                                    /* #14 - PAD                */
        /* 38 */    $"0000 0000"                                    /* #15 - PAD                */
        /* 3C */    $"0000 0000"                                    /* #16 - PAD                */

                                                                    /* Edit Text                */
        /* 40 */    $"007C"                                         /* Font    - System         */
        /* 42 */    $"0000"                                         /* Style   -                */
        /* 44 */    $"000C"                                         /* Size    - 12             */
        /* 46 */    ictb_color_black                                /* Foregnd - Black          */
        /* 4C */    ictb_color_white                                /* Backgnd - White          */
        /* 52 */    $"0001"                                         /* Mode                     */

                                                                    /* Static Text              */
        /* 54 */    $"0001"                                         /* Font    - Appl           */
        /* 56 */    $"0001"                                         /* Style   -                */
        /* 58 */    $"000C"                                         /* Size    - 12             */
        /* 5A */    ictb_color_black                                /* Foregnd - Black          */
        /* 60 */    ictb_color_white                                /* Backgnd - N/A            */
        /* 66 */    $"0001"                                         /* Mode                     */

                                                                    /* Version Information      */
        /* 68 */    $"0001"                                         /* Font    - Appl           */
        /* 6A */    $"0001"                                         /* Style   -                */
        /* 6C */    $"0009"                                         /* Size    - 9              */
        /* 6E */    ictb_color_light_blue                           /* Foregnd - Lt Blue        */
        /* 74 */    ictb_color_white                                /* Backgnd - N/A            */
        /* 7A */    $"0001"                                         /* Mode                     */

        /* 7C */    $"06 47 65 6E 65 76 61 00"                      /* "Geneva"                 */

    };


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    "X25_User_ID" Dialog Window - Set Password                                            + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    This Alert is NOT YET being used by the X.25 Interface Library.  It is here for       + */
/* +    future development.                                                                   + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    If "bounds_rectangle.left" is equal to zero, the DLOG will be aligned horizontally.   + */
/* +    If "bounds_rectangle.top"  is equal to zero, the DLOG will be aligned vertically.     + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'DLOG' ( dialog_set_pass, "New Password" ) {
    { 0, 0, 108, 250 },
    dBoxProc,
    invisible,
    noGoAway,
    0x0,
    dialog_set_pass,
    ""
};

resource 'DITL' ( dialog_set_pass ) {                   /* Main Connect to Gateway Server       */
    { /* array DITLarray: 7 elements */

        /* Item #1 ( OK_Button )                                                                */
        { 73, 160, 93, 220 },                                       /* Bounds Rectangle         */
        Button {                                                    /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "OK"                                                    /* Button Text              */
            },
        
        /* Item #2 ( Cancel_Button )                                                            */
        { 73, 30, 93, 90 },                                         /* Bounds Rectangle         */
        Button {                                                    /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "Cancel"                                                /* Button Text              */
            },
        
        /* Item #3 ( Old Password Label )                                                       */
        { 15, 30, 32, 145 },                                        /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "Old password"                                          /* Static Text              */
            },
        
        /* Item #4 ( Old Password Field )                                                       */
        { 15, 147, 31, 225 },                                       /* Bounds Rectangle         */
        EditText {                                                  /* Type of item             */
            enabled,                                                /* Item enabled?            */
            ""                                                      /* Edit Text                */
            },

        /* Item #5 ( New Password Label )                                                       */
        { 42, 30, 59, 145 },                                        /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "New password"                                          /* Static Text              */
            },
        
        /* Item #6 ( New Password Field )                                                       */
        { 42, 147, 58, 225 },                                       /* Bounds Rectangle         */
        EditText {                                                  /* Type of item             */
            enabled,                                                /* Item enabled?            */
            ""                                                      /* Edit Text                */
            },

        /* Item #7 ( Version String )                                                           */
        {224, 360, 238, 416},                                       /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            ""                                                      /* Static Text              */
            }

        }
    };

resource 'STR#' ( dialog_set_pass ) {             
    {
        "OK",                                                       /* [ 1]                     */
        "Cancel",                                                   /* [ 2]                     */
        "Old Password",                                             /* [ 3]                     */
        "",                                                         /* [ 4]                     */
        "New Password",                                             /* [ 5]                     */
        "",                                                         /* [ 6]                     */
        $$Shell("Build_Version_short")                              /* [ 7]                     */
    }
};


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    Alert - Access Has Been Refused                                                       + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    This Alert is NOT used by the X.25 Interface Library.  It is supplied for any         + */
/* +    Developer that may want an Alert that matches the that used by the X.25 Chooser.      + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'ALRT' ( dialog_access_refused, "Acc Denied" ) {       /* The alert box                */
    { 0, 0, 130, 358 },                                             /* Bounds Rectangle         */
    dialog_access_refused, {                                        /* 'DITL' ID                */
        OK, visible, sound1,                                        /* Stage 1                  */
        OK, visible, sound1,                                        /* Stage 2                  */
        OK, visible, sound1,                                        /* Stage 3                  */
        OK, visible, sound1                                         /* Stage 4                  */
        }
    };

resource 'actb' ( dialog_access_refused ) {                     /* Dialog Color Table           */
    {                                                               /* (Reserved fields)        */
        wContentColor,      color_white;                            /* Content Color            */
        wFrameColor,        color_black;                            /* Frame Color              */
        wTextColor,         color_black;                            /* Text Color               */
        wHiliteColor,       color_black;                            /* Hilite Color     - N/A   */
        wTitleBarColor,     color_black                             /* Title Bar Color  - N/A   */
        }
    };

resource 'DITL' ( dialog_access_refused ) {                     /* Access has been Refused      */
    { /* array DITLarray: 3 elements */

        /* Item #1 ( OK_Button )                                                                */
        { 98, 136, 118, 221 },                                      /* Bounds Rectangle         */
        Button {                                                    /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "OK"                                                    /* Button Text              */
            },
        
        /* Item #2 ( System's "Stop" Icon )                                                     */
        { 16, 16, 48, 48 },                                         /* Bounds Rectangle         */
        Icon {                                                      /* Type of item             */
            disabled,                                               /* Item enabled?            */
            0                                                       /* Icon Number              */
            },

        /* Item #3 ( Message to User )                                                          */
        { 16, 72, 64, 333 },                                        /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "Access has been refused.\n"                            /* Static Text              */
            "Please re-enter user name "
            "and password."
            }

    }
};

data 'ictb' ( dialog_access_refused ) {                         /* DITL Color Table             */
        /* 00 */    $"0000 0000"                                    /* #01 - OK Button          */
        /* 04 */    $"0000 0000"                                    /* #02 - Stop Icon          */
        /* 08 */    $"500F 0010"                                    /* #03 - Msg - Static Text  */
        /* 0C */    $"0000 0000"                                    /* #04 - PAD                */

                                                                    /* Static Text              */
        /* 10 */    $"0001"                                         /* Font  - Appl             */
        /* 12 */    $"0001"                                         /* Style -                  */
        /* 14 */    $"000C"                                         /* Size  - 12               */
        /* 16 */    $"0000 7F7F 0000"                               /* Foregnd -                */
        /* 1C */    $"0000 0000 0000"                               /* Backgnd - N/A            */
        /* 22 */    $"0001"                                         /* Mode                     */

    };



/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    Alert - X.25 Server Administration Messages                                           + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    If "bounds_rectangle.left" is equal to zero, the ALERT will be aligned horizontally.  + */
/* +    If "bounds_rectangle.top"  is equal to zero, the DLOG will be aligned vertically.     + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'ALRT' ( alert_admin, "X.25 Administration" ) {
    { 0, 0, 126, 448 },                                         /* Bounds Rectangle             */
    alert_admin, {                                                  /* 'DITL' ID                */
        OK, visible, sound1,                                        /* Stage 1                  */
        OK, visible, sound1,                                        /* Stage 2                  */
        OK, visible, sound1,                                        /* Stage 3                  */
        OK, visible, sound1                                         /* Stage 4                  */
        }
    };

resource 'actb' (alert_admin ) {                                /* Alert Color Table            */
    {                                                               /* (Reserved fields)        */
        wContentColor,      color_white;                            /* Content Color            */
        wFrameColor,        color_red;                              /* Frame Color              */
        wTextColor,         color_black;                            /* Text Color               */
        wHiliteColor,       color_black;                            /* Hilite Color     - N/A   */
        wTitleBarColor,     color_black                             /* Title Bar Color  - N/A   */
        }
    };

resource 'DITL' ( alert_admin ) {                               /* Administration Messages      */
    { /* array DITLarray: 3 elements */

        /* Item #1 ( OK_Button )                                                                */
        { 92, 356, 114, 426 },                                      /* Bounds Rectangle         */
        Button {                                                    /* Type of item             */
            enabled,                                                /* Item enabled?            */
            "OK"                                                    /* Button Text              */
            },
        
        /* Item #2 ( System's "Warning" Icon )                                                  */
        { 8, 18, 40, 50 },                                          /* Bounds Rectangle         */
        Icon {                                                      /* Type of item             */
            disabled,                                               /* Item enabled?            */
            2                                                       /* Icon Number              */
            },

        /* Item #3 ( Message to User )                                                          */
        { 12, 68, 86, 430 },                                        /* Bounds Rectangle         */
        StaticText {                                                /* Type of item             */
            disabled,                                               /* Item enabled?            */
            "^0"                                                    /* Static Text              */
            }

    }
};


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resource for Chooser Access                                                      + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'STR#' ( strs_chooser, "", purgeable ) {
        {
        /* 01 */        "MacX25"                ,   /*  Name of the Package to Load             */
        /* 02 */        "PAPA"                  ,   /*  Name of the Resource to Load            */
        /* 03 */        "-8192"                 ,   /*  Number of the Resource to Load          */
        }
    };


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resource for Open Book Access                                                    + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'STR#' ( strs_openbook, "", purgeable ) {
        {
        /* 01 */        "MacX25 Open Book"      ,   /*  Name of the File to Load From           */
        /* 02 */        "CODE"                  ,   /*  Name of the Resource to Load            */
        /* 03 */        "257"                   ,   /*  Number of the Resource to Load          */
        /* 04 */        "X.25 Server"           ,   /*  Name of the NBP Record                  */
        /* 05 */        "X.25 Connection"       ,   /*  Name of the Connection Record           */
        }
    };


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resources for Error Message Decode                                               + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    Note: Imbedding a "^n" in the string will format and insert data as follows:          + */
/* +                                                                                          + */
/* +        ^1  = status_code formatted in decimal (signed if negative)                       + */
/* +        ^2  = high order byte of status_code formatted in decimal (signed if negative)    + */
/* +        ^3  = low order byte of status_code formatted in decimal (signed if negative)     + */
/* +                                                                                          + */
/* +        ^4  = status_code formatted in un-signed decimal                                  + */
/* +        ^5  = high order byte of status_code formatted in un-signed decimal               + */
/* +        ^6  = low order byte of status_code formatted in un-signed decimal                + */
/* +                                                                                          + */
/* +        ^7  = status_code formatted in hexidecimal                                        + */
/* +        ^8  = high order byte of status_code formatted in hexidecimal                     + */
/* +        ^9  = low order byte of status_code formatted in hexidecimal                      + */
/* +                                                                                          + */
/* +        ^^  = Escape sequence - inserts a single "^"                                      + */
/* +                                                                                          + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */


resource 'STR#' ( strs_error_decode + 0x00, "", purgeable ) {
        {
        /* - */ "No Error on Call"                                                  ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - I/O Has Been Scheduled"                                     ,
        /* 2 */     " - I/O Request Would Block"                                    ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - User Cancelled the Request"                                 ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x01, "", purgeable ) {
        {
        /* - */ "Procedure Error on Call"                                           ,
        /* 0 */     ""                                                              ,
        /* 1 */     ""                                                              ,
        /* 2 */     " - Resource Usage Not Allowed"                                 ,
        /* 3 */     " - Async I/O Not Allowed"                                      ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - Prior Initialization Call to X25_Open"                      ,
        /* 9 */     " - No Initialization Call to X25_Open"                         ,
        /* A */     " - Existing VCCB Allocation"                                   ,
        /* B */     " - No VCCB Allocation"                                         ,
        /* C */     " - VCCB Not Closed"                                            ,
        /* D */     " - VCCB Not Open"                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x02, "", purgeable ) {
        {
        /* - */ "Procedure Error on Call"                                           ,
        /* 0 */     " - Temporary"                                                  ,
        /* 1 */     ""                                                              ,
        /* 2 */     " - Existing MacX25 Server Connection"                          ,
        /* 3 */     " - No MacX25 Server Connection"                                ,
        /* 4 */     " - MacX25 Server Connection State ( Expected ^6 / Was ^5 )"    ,
        /* 5 */     ""                                                              ,
        /* 6 */     " - User Already Validated"                                     ,
        /* 7 */     " - User Not Validated"                                         ,
        /* 8 */     " - User Validation State ( Expected ^6 / Was ^5 )"             ,
        /* 9 */     ""                                                              ,
        /* A */     " - Prior X.25 VC Established"                                  ,
        /* B */     " - No X.25 VC Established"                                     ,
        /* C */     " - X.25 VC State ( Expected ^6 / Was ^5 )"                     ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x03, "", purgeable ) {
        {
        /* - */ "Communications Error to X.25 Server"                               ,
        /* 0 */     " - Transmission Error"                                         ,
        /* 1 */     " - ADSP Shutdown"                                              ,
        /* 2 */     " - IPC Shutdown"                                               ,
        /* 3 */     " - ADSP Error (Error Code = ^1)"                               ,
        /* 4 */     " - IPC Error (Error Code = ^1)"                                ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     " - MacX25 Server Error (Error Code = ^1)"                      ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x04, "", purgeable ) {
        {
        /* - */ "Internal Consistency Check"                                        ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Global Storage Area Corrupted"                              ,
        /* 2 */     " - VCCB Area Corrupted"                                        ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x05, "", purgeable ) {
        {
        /* - */ "Needed Support is Not Available"                                   ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Library ADSP Interface"                                     ,
        /* 2 */     " - Library IPC Interface"                                      ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x06, "", purgeable ) {
        {
        /* - */ "A Needed Component is Not Available"                               ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - AppleTalk 'mpp' Driver Missing"                             ,
        /* 2 */     " - AppleTalk 'mpp' Version (Minimum Required ^6 / Was ^5)"     ,
        /* 3 */     " - AppleTalk 'ADSP' Missing"                                   ,
        /* 4 */     " - AppleTalk 'ADSP' Version (Minimum Required ^6 / Was ^5)"    ,
        /* 5 */     " - 'AppleIPC' Missing"                                         ,
        /* 6 */     " - 'AppleIPC' Version (Minimum Required ^6 / Was ^5)"          ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x07, "", purgeable ) {
        {
        /* - */ "Requested Server is Not Accessible"                                ,
        /* 0 */     " - Server is Not Registered on AppleTalk Network"              ,
        /* 1 */     " - Server Refused Connection"                                  ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     " - Server Has No Available Virtual Circuits"                   ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x08, "", purgeable ) {
        {
        /* - */ "Server Authentication Failure"                                     ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Incompatible Authenticator Version (Expected ^6 / Was ^5)"  ,
        /* 2 */     " - Invalid Authenticator Msg Received"                         ,
        /* 3 */     " - No Authenticator Present"                                   ,
        /* 4 */     " - Authenticator Has Shutdown"                                 ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - Overlength User Name"                                       ,
        /* 9 */     " - Overlength User Password"                                   ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     " - Invalid User Name"                                          ,
        /* D */     " - Invalid User Password"                                      ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x0A, "", purgeable ) {
        {
        /* - */ "Macintosh O.S. Error"                                              ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - O.S. Error (Error Code = ^1)"                               ,
        /* 2 */     " - Unable to Allocate Task Memory (^4 Bytes Requested)"        ,
        /* 3 */     " - Unable to Allocate System Memory (^4 Bytes Requested)"      ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - Low Remaining Stack Space (^1 Bytes Remaining)"             ,
        /* 9 */     ""                                                              ,
        /* A */     " - Library VBL Task Install Failed"                            ,
        /* B */     " - Library Stack Task Install Failed"                          ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x10, "", purgeable ) {
        {
        /* - */ "I/O Error"                                                         ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Transmission Aborted by Program Request"                    ,
        /* 2 */     " - Transmission Timeout Occurred"                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x11, "", purgeable ) {
        {
        /* - */ "I/O Read Error"                                                    ,
        /* 0 */     " - Buffer Error"                                               ,
        /* 1 */     " - Nil Buffer Pointer"                                         ,
        /* 2 */     " - Buffer Alignment Error"                                     ,
        /* 3 */     " - Buffer Overflow (^1 Bytes Required)"                        ,
        /* 4 */     ""                                                              ,
        /* 5 */     " - Prior Read Request Pending"                                 ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x12, "", purgeable ) {
        {
        /* - */ "I/O Write Error"                                                   ,
        /* 0 */     " - Buffer Error"                                               ,
        /* 1 */     " - Nil Buffer Pointer"                                         ,
        /* 2 */     " - Buffer Alignment Error"                                     ,
        /* 3 */     " - Buffer Overflow"                                            ,
        /* 4 */     " - Buffer Underflow"                                           ,
        /* 5 */     " - Prior Write Request Pending"                                ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x13, "", purgeable ) {
        {
        /* - */ "I/O Aux Read Error"                                                ,
        /* 0 */     " - Buffer Error"                                               ,
        /* 1 */     " - Nil Buffer Pointer"                                         ,
        /* 2 */     " - Buffer Alignment Error"                                     ,
        /* 3 */     " - Buffer Overflow (^1 Bytes Required)"                        ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x14, "", purgeable ) {
        {
        /* - */ "I/O Aux Write Error"                                               ,
        /* 0 */     " - Buffer Error"                                               ,
        /* 1 */     " - Nil Buffer Pointer"                                         ,
        /* 2 */     " - Buffer Alignment Error"                                     ,
        /* 3 */     " - Buffer Overflow"                                            ,
        /* 4 */     " - Buffer Underflow"                                           ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x18, "", purgeable ) {
        {
        /* - */ "X.25 Message Header Error"                                         ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Unknown Header (Header Type Was 0x^7)"                      ,
        /* 2 */     " - Invalid Header Destination  (Expected 0x^9 / Was 0x^8)"     ,
        /* 3 */     " - Invalid Header Source  (Expected 0x^9 / Was 0x^8)"          ,
        /* 4 */     " - Invalid Header Version  (Expected 0x^9 / Was 0x^8)"         ,
        /* 5 */     " - Returned Message Rejected by Remote"                        ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - Unexpected Header (Header Type Was 0x^7)"                   ,
        /* 9 */     ""                                                              ,
        /* A */     " - Underlength Header (Length was 0x^7 Bytes)"                 ,
        /* B */     " - Overlength Header (Length was 0x^7 Bytes)"                  ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x19, "", purgeable ) {
        {
        /* - */ "X.25 Message Error"                                                ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Unknown Message (Message Type Was 0x^7)"                    ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     " - Invalid Message Version  (Expected 0x^9 / Was 0x^8)"        ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - Unexpected Message (Message Type Was 0x^7)"                 ,
        /* 9 */     ""                                                              ,
        /* A */     " - Underlength Message (Length was 0x^7 Bytes)"                ,
        /* B */     " - Overlength Message (Length was 0x^7 Bytes)"                 ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x1A, "", purgeable ) {
        {
        /* - */ "X.25 Packet Error"                                                 ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Overlength Packet (Packet Length Was 0x^9)"                 ,
        /* 2 */     " - Underlength Packet (Packet Length Was 0x^9)"                ,
        /* 3 */     " - Unexpected Packet (Packet Type Was 0x^9)"                   ,
        /* 4 */     " - Unknown Packet (Packet Type Was 0x^9)"                      ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x20, "", purgeable ) {
        {
        /* - */ "X.25 Packet Encode Error"                                          ,
        /* 0 */     " - Syntax Error (Input Position ^1)"                           ,
        /* 1 */     " - Underlength Field (Input Position ^1)"                      ,
        /* 2 */     " - Overlength Field (Input Position ^1)"                       ,
        /* 3 */     " - Field Value too Small (Input Position ^1)"                  ,
        /* 4 */     " - Field Value too Large (Input Position ^1)"                  ,
        /* 5 */     ""                                                              ,
        /* 6 */     " - Field Value Illegal (Input Position ^1)"                    ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - Duplicate Facility Requested (Input Position ^1)"           ,
        /* 9 */     " - Inconsistent Facility Requested (Input Position ^1)"        ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     " - Too Much Facility Data Supplied (Input Position ^1)"        ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x21, "", purgeable ) {
        {
        /* - */ "X.25 Packet Encode Error"                                          ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Overlength Data Packet (Max Size is ^1 Bytes)"              ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     " - Invalid Network Address Configured"                         ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x22, "", purgeable ) {
        {
        /* - */ "X.25 Packet Decode Error"                                          ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Overlength Data Packet (Max Size is ^1 Bytes)"              ,
        /* 2 */     " - Overlength Packet (Max Size is ^1 Bytes)"                   ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - Error in Address Field"                                     ,
        /* 9 */     " - Error in Facility Field"                                    ,
        /* A */     " - Error in User Data Field"                                   ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x28, "", purgeable ) {
        {
        /* - */ "X.25 Call Connection Error"                                        ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Call Cleared (Cause 0x^8 / Diag 0x^9)"                      ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x2A, "", purgeable ) {
        {
        /* - */ "X.25 Call Registration Format Error"                               ,
        /* 0 */     " - (Error Code = ^1)"                                          ,
        /* 1 */     " - Invalid Registration Code"                                  ,
        /* 2 */     " - No Primary Code"                                            ,
        /* 3 */     " - Invalid Data Field Size"                                    ,
        /* 4 */     " - Invalid Mask Field Size"                                    ,
        /* 5 */     " - Data / Mask Size Mis-Match"                                 ,
        /* 6 */     " - Invalid Mask Field"                                         ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x2B, "", purgeable ) {
        {
        /* - */ "X.25 Duplicate Call Registration Refused"                          ,
        /* 0 */     " - (Error Code = ^1)"                                          ,
        /* 1 */     ""                                                              ,
        /* 2 */     " - User Data Field"                                            ,
        /* 3 */     ""                                                              ,
        /* 4 */     " - Calling Address Field"                                      ,
        /* 5 */     " - Called Address Field"                                       ,
        /* 6 */     " - Calling NSAP Field"                                         ,
        /* 7 */     " - Called NSAP Field"                                          ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     " - CUG Field"                                                  ,
        /* B */     " - BCUG Field"                                                 ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     " - Reverse Charging Field"                                     ,
        /* F */     " - Fast Select Field"                                          ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x30, "", purgeable ) {
        {
        /* - */ "Chooser Access Error"                                              ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Chooser Not Available"                                      ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - NBP Data Format Error"                                      ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_error_decode + 0x31, "", purgeable ) {
        {
        /* - */ "Address Book Error"                                                ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Address Book Not Available"                                 ,
        /* 2 */     " - Open Error (Error Code Was 0x^9)"                           ,
        /* 3 */     " - Access Error (Error Code Was 0x^9)"                         ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     " - NBP Data Format in Error"                                   ,
        /* 9 */     " - Connection Record Format in Error"                          ,
        /* A */     " - No Server Record Available"                                 ,
        /* B */     " - No Connection Record Available"                             ,
        /* C */     " - No Information Available"                                   ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
    
    
    
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resource for Extended Text of Clear Packet decode                                + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    Note: Imbedding a "^n" in the string will format and insert data as follows:          + */
/* +                                                                                          + */
/* +        ^2  = cause code formatted in decimal (signed if negative)                        + */
/* +        ^3  = diagnostic code formatted in decimal (signed if negative)                   + */
/* +                                                                                          + */
/* +        ^5  = cause code formatted in un-signed decimal                                   + */
/* +        ^6  = diagnostic code formatted in un-signed decimal                              + */
/* +                                                                                          + */
/* +        ^8  = cause code formatted in hexidecimal                                         + */
/* +        ^9  = diagnostic code formatted in hexidecimal                                    + */
/* +                                                                                          + */
/* +        ^^  = Escape sequence - inserts a single "^"                                      + */
/* +                                                                                          + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'STR#' ( strs_decode_clear, "", purgeable ) {
        {
        /* 00      */   ""                                                                      ,
        /* 01 - ?? */   "CLR CONF - Confirmed"                                                  ,
        /* 02      */   ""                                                                      ,
        /* 03      */   ""                                                                      ,
        /* 04      */   ""                                                                      ,
        /* 05      */   ""                                                                      ,
        /* 06      */   ""                                                                      ,
        /* 07      */   ""                                                                      ,
        /* 08      */   ""                                                                      ,
        /* 09      */   ""                                                                      ,

        /* 10      */   ""                                                                      ,
        /* 11 - ?? */   "CLR MacX25 0 - Call cleared, server originated for reason = ^1"        ,
        /* 12 - 12 */   "CLR MacX25 0 - Call cleared, user LUN cleared or never existed"        ,
        /* 13 - 16 */   "CLR MacX25 0 - Call cleared, access link is down"                      ,
        /* 14 - 13 */   "CLR MacX25 0 - Call cleared, flow control violation"                                                                       ,
        /* 15 - 11 */   "CLR MacX25 0 - Call cleared, no listener agent to register request with"                                                                       ,
        /* 16      */   ""                                                                      ,
        /* 17      */   ""                                                                      ,
        /* 18      */   ""                                                                      ,
        /* 19      */   ""                                                                      ,

        /* 20      */   ""                                                                      ,
        /* 21 - ?? */   "CLR UNK ^6 - Call cleared, cause code = ^5"                            ,
        /* 22 - 8x */   "CLR DTE ^6 - Call cleared, remote DTE originated for reason ^5"        ,
        /* 23 - 00 */   "CLR DTE ^6 - Call cleared, remote DTE originated for unknown reason"   ,
        /* 24 - 01 */   "CLR OCC ^6 - Call cleared, number busy"                                ,
        /* 25 - 03 */   "CLR INV ^6 - Call cleared, invalid facility requested"                 ,
        /* 26 - 05 */   "CLR NC ^6 - Call cleared, temporary network problem"                   ,
        /* 27 - 09 */   "CLR DER ^6 - Call cleared, number out of order"                        ,
        /* 28 - 0B */   "CLR NA ^6 - Call cleared, access to this number is barred"             ,
        /* 29 - 0D */   "CLR NP ^6 - Call cleared, number not assigned"                         ,
        /* 30 - 11 */   "CLR RPE ^6 - Call cleared, network detected remote procedure error"    ,
        /* 31 - 13 */   "CLR ERR ^6 - Call cleared, network detected local procedure error"     ,
        /* 32 - 15 */   "CLR ROO ^6 - Call cleared, cannot be routed as requested"              ,
        /* 33 - 19 */   "CLR RNA ^6 - Call cleared, reverse charging refused"                   ,
        /* 34 - 21 */   "CLR ID ^6 - Call cleared, incompatible destination"                    ,
        /* 35 - 29 */   "CLR FNA ^6 - Call cleared, fast select refused"                        ,
        /* 36 - 39 */   "CLR SA ^6 - Call cleared, ship cannot be contacted"                    ,
        /* 37 - 83 */   "CLR DTE ^6 - Call cleared, invalid facility requested"                 ,
        /* 38 - 99 */   "CLR DTE ^6 - Call cleared, reverse charging refused"                   ,
        /* 39 - A9 */   "CLR DTE ^6 - Call cleared, fast select refused"                        ,
        }
    };


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resource for Extended Text of Interrupt Packet decode                            + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    Note: Imbedding a "^n" in the string will format and insert data as follows:          + */
/* +                                                                                          + */
/* +        ^2  = cause code formatted in decimal (signed if negative)                        + */
/* +        ^3  = diagnostic code formatted in decimal (signed if negative)                   + */
/* +                                                                                          + */
/* +        ^5  = cause code formatted in un-signed decimal                                   + */
/* +        ^6  = diagnostic code formatted in un-signed decimal                              + */
/* +                                                                                          + */
/* +        ^8  = cause code formatted in hexidecimal                                         + */
/* +        ^9  = diagnostic code formatted in hexidecimal                                    + */
/* +                                                                                          + */
/* +        ^^  = Escape sequence - inserts a single "^"                                      + */
/* +                                                                                          + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'STR#' ( strs_decode_interrupt, "", purgeable ) {
        {
        /* 00      */   ""                                                                      ,
        /* 01 - ?? */   "INT CONF - Confirmed"                                                  ,
        /* 02      */   ""                                                                      ,
        /* 03      */   ""                                                                      ,
        /* 04      */   ""                                                                      ,
        /* 05      */   ""                                                                      ,
        /* 06      */   ""                                                                      ,
        /* 07      */   ""                                                                      ,
        /* 08      */   ""                                                                      ,
        /* 09      */   ""                                                                      ,

        /* 10      */   ""                                                                      ,
        /* 11 - ?? */   "INT MacX25 0 - server originated for reason = ^1"                      ,
        /* 12      */   ""                                                                      ,
        /* 13      */   ""                                                                      ,
        /* 14      */   ""                                                                      ,
        /* 15      */   ""                                                                      ,
        /* 16      */   ""                                                                      ,
        /* 17      */   ""                                                                      ,
        /* 18      */   ""                                                                      ,
        /* 19      */   ""                                                                      ,

        /* 20      */   ""                                                                      ,
        /* 21 - ?? */   "INT UNK"                                                               ,
        /* 22      */   ""                                                                      ,
        /* 23      */   ""                                                                      ,
        /* 24      */   ""                                                                      ,
        /* 25      */   ""                                                                      ,
        /* 26      */   ""                                                                      ,
        /* 27      */   ""                                                                      ,
        /* 28      */   ""                                                                      ,
        /* 29      */   ""                                                                      ,
        }
    };
                    

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resource for Extended Text of Reset Packet decode                                + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    Note: Imbedding a "^n" in the string will format and insert data as follows:          + */
/* +                                                                                          + */
/* +        ^2  = cause code formatted in decimal (signed if negative)                        + */
/* +        ^3  = diagnostic code formatted in decimal (signed if negative)                   + */
/* +                                                                                          + */
/* +        ^5  = cause code formatted in un-signed decimal                                   + */
/* +        ^6  = diagnostic code formatted in un-signed decimal                              + */
/* +                                                                                          + */
/* +        ^8  = cause code formatted in hexidecimal                                         + */
/* +        ^9  = diagnostic code formatted in hexidecimal                                    + */
/* +                                                                                          + */
/* +        ^^  = Escape sequence - inserts a single "^"                                      + */
/* +                                                                                          + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'STR#' ( strs_decode_reset, "", purgeable ) {
        {
        /* 00      */   ""                                                                      ,
        /* 01 - ?? */   "RESET CONF - Confirmed"                                                ,
        /* 02      */   ""                                                                      ,
        /* 03      */   ""                                                                      ,
        /* 04      */   ""                                                                      ,
        /* 05      */   ""                                                                      ,
        /* 06      */   ""                                                                      ,
        /* 07      */   ""                                                                      ,
        /* 08      */   ""                                                                      ,
        /* 09      */   ""                                                                      ,

        /* 10      */   ""                                                                      ,
        /* 11 - ?? */   "RESET MacX25 0 - server originated for reason = ^1"                    ,
        /* 12      */   ""                                                                      ,
        /* 13      */   ""                                                                      ,
        /* 14      */   ""                                                                      ,
        /* 15      */   ""                                                                      ,
        /* 16      */   ""                                                                      ,
        /* 17      */   ""                                                                      ,
        /* 18      */   ""                                                                      ,
        /* 19      */   ""                                                                      ,

        /* 20      */   ""                                                                      ,
        /* 21 - ?? */   "RESET UNK ^6 - cause code = ^5"                                        ,
        /* 22 - 8x */   "RESET DTE ^6 - remote DTE originated for reason ^5"                    ,
        /* 23 - 00 */   "RESET DTE ^6 - Reset by remote device, data may be lost"               ,
        /* 24 - 03 */   "RESET OCC ^6 - Reset by network, remote procedure error, data may be lost" ,
        /* 25 - 05 */   "RESET RPE ^6 - Reset by network, local procedure error, data may be lost"  ,
        /* 26 - 07 */   "RESET ERR ^6 - Reset due to temporary network problem, data may be lost"   ,
        /* 27 - 0B */   ""                                                                      ,
        /* 28 - 0D */   ""                                                                      ,
        /* 29 - 0D */   ""                                                                      ,
        }
    };
                    

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resources for Diagnostic Codes Decode                                            + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    Note: Imbedding a "^n" in the string will format and insert data as follows:          + */
/* +                                                                                          + */
/* +        ^3  = diagnostic code formatted in decimal (signed if negative)                   + */
/* +                                                                                          + */
/* +        ^6  = diagnostic code formatted in un-signed decimal                              + */
/* +                                                                                          + */
/* +        ^9  = diagnostic code formatted in hexidecimal                                    + */
/* +                                                                                          + */
/* +        ^^  = Escape sequence - inserts a single "^"                                      + */
/* +                                                                                          + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */


resource 'STR#' ( strs_decode_diagnostic + 0x00, "", purgeable ) {
        {
        /* - */ ""                                                                  ,
        /* 0 */     "No Additional Information"                                     ,
        /* 1 */     "Invalid P(S)"                                                  ,
        /* 2 */     "Invalid P(R)"                                                  ,
        /* 3 */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* 4 */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* 5 */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* 6 */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* 7 */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* 8 */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* 9 */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* A */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* B */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* C */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* D */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* E */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        /* F */     "No Additional Information - (Diagnostic Code Was 0x^9)"        ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x01, "", purgeable ) {
        {
        /* - */ "Packet Type Invalid"                                               ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - For State r1"                                               ,
        /* 2 */     " - For State r2"                                               ,
        /* 3 */     " - For State r3"                                               ,
        /* 4 */     " - For State p1"                                               ,
        /* 5 */     " - For State p2"                                               ,
        /* 6 */     " - For State p3"                                               ,
        /* 7 */     " - For State p4"                                               ,
        /* 8 */     " - For State p5"                                               ,
        /* 9 */     " - For State p6"                                               ,
        /* A */     " - For State p7"                                               ,
        /* B */     " - For State d1"                                               ,
        /* C */     " - For State d2"                                               ,
        /* D */     " - For State d3"                                               ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_decode_diagnostic + 0x02, "", purgeable ) {
        {
        /* - */ "Packet Not Allowed"                                                ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Unidentifiable Packet"                                      ,
        /* 2 */     " - Call on a One-Way Logical Channel"                          ,
        /* 3 */     " - Invalid Packet Type on PVC"                                 ,
        /* 4 */     " - Packet on Unassigned Logical Channel"                       ,
        /* 5 */     " - Reject Not Subscribed To"                                   ,
        /* 6 */     " - Packet Too Short"                                           ,
        /* 7 */     " - Packet Too Long"                                            ,
        /* 8 */     " - Invalid GFI"                                                ,
        /* 9 */     " - Restart or Registration Packet With Non-Zero LCI"           ,
        /* A */     " - Packet Type Incompatible With Facility"                     ,
        /* B */     " - Unauthorized Interrupt Confirmation"                        ,
        /* C */     " - Unauthorized Interrupt"                                     ,
        /* D */     " - Unauthorized Reject"                                        ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x03, "", purgeable ) {
        {
        /* - */ "Time Expired"                                                      ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - For Incoming Call"                                          ,
        /* 2 */     " - For Clear Indication"                                       ,
        /* 3 */     " - For Reset Indication"                                       ,
        /* 4 */     " - For Restart Indication"                                     ,
        /* 5 */     " - For Call Deflection"                                        ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x04, "", purgeable ) {
        {
        /* - */ "Call Setup/Clearing or Registration"                               ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Facility / Registration Code Not Allowed"                   ,
        /* 2 */     " - Facility Parameter Not Allowed"                             ,
        /* 3 */     " - Invalid Called Address"                                     ,
        /* 4 */     " - Invalid Calling Address"                                    ,
        /* 5 */     " - Invalid Facility / Registration Length"                     ,
        /* 6 */     " - Incoming Call Barred"                                       ,
        /* 7 */     " - No Logical Channel Available"                               ,
        /* 8 */     " - Call Collision"                                             ,
        /* 9 */     " - Duplicate Facility Requested"                               ,
        /* A */     " - Non-Zero Address Length"                                    ,
        /* B */     " - Non-Zero Facility Length"                                   ,
        /* C */     " - Facility Not Provided When Expected"                        ,
        /* D */     " - Invalid CCITT DTE Facility"                                 ,
        /* E */     " - Maximum Number of Call Deflections"                         ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x05, "", purgeable ) {
        {
        /* - */ "Miscellaneous"                                                     ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Improper Cause Code From DTE"                               ,
        /* 2 */     " - Not-Aligned Octet"                                          ,
        /* 3 */     " - Inconsistent Q-Bit Setting"                                 ,
        /* 4 */     " - NUI Problem"                                                ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x06, "", purgeable ) {
        {
        /* - */ "Code Not Assigned (Code Was 0x^9)"                                 ,
        /* 0 */     ""                                                              ,
        /* 1 */     ""                                                              ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x07, "", purgeable ) {
        {
        /* - */ "International Problem"                                             ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Remote Network Problem"                                     ,
        /* 2 */     " - International Network Problem"                              ,
        /* 3 */     " - International Link Out of Order"                            ,
        /* 4 */     " - International Link Busy"                                    ,
        /* 5 */     " - Transit Network Facility Problem"                           ,
        /* 6 */     " - Remote Network Facility Problem"                            ,
        /* 7 */     " - International Routing Problem"                              ,
        /* 8 */     " - Temporary Routing Problem"                                  ,
        /* 9 */     " - Unknown Called DNIC"                                        ,
        /* A */     " - Maintenance Action"                                         ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x08, "", purgeable ) {
        {
        /* - */ "DTE Specific Information (Code Was 0x^9)"                          ,
        /* 0 */     ""                                                              ,
        /* 1 */     ""                                                              ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    
resource 'STR#' ( strs_decode_diagnostic + 0x09, "", purgeable ) {
        {
        /* - */ "Time Expired or Retransmission Count Exceeded"                     ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - For Interrupt"                                              ,
        /* 2 */     " - For Data Packet"                                            ,
        /* 3 */     " - For Reject"                                                 ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x0A, "", purgeable ) {
        {
        /* - */ "DTE Specific Signal"                                               ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - DTE Operational"                                            ,
        /* 2 */     " - DTE Not Operational"                                        ,
        /* 3 */     " - DTE Resource Constrained"                                   ,
        /* 4 */     " - Fast Select Not Subscribed To"                              ,
        /* 5 */     " - Invalid Partially Full Data Packet"                         ,
        /* 6 */     " - D-Bit Procedure Not Supported"                              ,
        /* 7 */     " - Registration / Cancellation Confirmed"                      ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x0B, "", purgeable ) {
        {
        /* - */ "Code Not Assigned (Code Was 0x^9)"                                 ,
        /* 0 */     ""                                                              ,
        /* 1 */     ""                                                              ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x0C, "", purgeable ) {
        {
        /* - */ "Code Not Assigned (Code Was 0x^9)"                                 ,
        /* 0 */     ""                                                              ,
        /* 1 */     ""                                                              ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x0D, "", purgeable ) {
        {
        /* - */ "Code Not Assigned (Code Was 0x^9)"                                 ,
        /* 0 */     ""                                                              ,
        /* 1 */     ""                                                              ,
        /* 2 */     ""                                                              ,
        /* 3 */     ""                                                              ,
        /* 4 */     ""                                                              ,
        /* 5 */     ""                                                              ,
        /* 6 */     ""                                                              ,
        /* 7 */     ""                                                              ,
        /* 8 */     ""                                                              ,
        /* 9 */     ""                                                              ,
        /* A */     ""                                                              ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x0E, "", purgeable ) {
        {
        /* - */ "OSI Network Service Problem"                                       ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Disconnected (Transient)"                                   ,
        /* 2 */     " - Disconnected (Permanent)"                                   ,
        /* 3 */     " - Connection Rejection - Unknown (Transient)"                 ,
        /* 4 */     " - Connection Rejection - Unknown (Permanent)"                 ,
        /* 5 */     " - Connection Rejection - QOS (Transient)"                     ,
        /* 6 */     " - Connection Rejection - QOS (Permanent)"                     ,
        /* 7 */     " - Connection Rejection - NSAP (Transient)"                    ,
        /* 8 */     " - Connection Rejection - NSAP (Permanent)"                    ,
        /* 9 */     " - Reset (Reason Unspecified)"                                 ,
        /* A */     " - Reset (Congestion)"                                         ,
        /* B */     " - Connection Rejection - QOS Unknown (Permanent)"             ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

resource 'STR#' ( strs_decode_diagnostic + 0x0F, "", purgeable ) {
        {
        /* - */ "Higher Level Initiated"                                            ,
        /* 0 */     ""                                                              ,
        /* 1 */     " - Disconnected (Normal)"                                      ,
        /* 2 */     " - Disconnected (Abnormal)"                                    ,
        /* 3 */     " - Disconnected (Incompatible)"                                ,
        /* 4 */     " - Connection Rejection - Unknown (Transient)"                 ,
        /* 5 */     " - Connection Rejection - Unknown (Permanent)"                 ,
        /* 6 */     " - Connection Rejection - QOS (Transient)"                     ,
        /* 7 */     " - Connection Rejection - QOS (Permanent)"                     ,
        /* 8 */     " - Connection Rejection - (Incompatible)"                      ,
        /* 9 */     " - Connection Rejection - (Unknown Protocol ID)"               ,
        /* A */     " - Reset (User Resynchronization)"                             ,
        /* B */     ""                                                              ,
        /* C */     ""                                                              ,
        /* D */     ""                                                              ,
        /* E */     ""                                                              ,
        /* F */     ""                                                              ,
        }
    };
    

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                                          + */
/* +    STR# Resource for X.25 Admin message decode                                           + */
/* +                                                                                          + */
/* +------------------------------------------------------------------------------------------+ */
/* +                                                                                          + */
/* +    Note: Imbedding a "^1" in the string will format and insert the shutdown time         + */
/* +                                                                                          + */
/* +          Imbedding a "^^P" in the string will format and insert the Server Name.         + */
/* +                                                                                          + */
/* +          ^^    = Escape sequence - inserts a single "^"                                  + */
/* +                                                                                          + */
/* +                                                                                          + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

resource 'STR#' ( strs_decode_admin, "", purgeable ) {
        {
        /* 01 */        "X.25 Server \"^^p\" has been "         /*  Shutdown Complete Msg       */
                        "shutdown."                         , 
        /* 02 */        "X.25 Server \"^^p\" is shutting "      /*  Shutdown Msg - 1 minute     */
                        "down in ^1 minute."                ,
        /* 03 */        "X.25 Server \"^^p\" is shutting "      /*  Shutdown Msg - n minutes    */
                        "down in ^1 minutes."               ,
        /* 04 */        "X.25 Server \"^^p\" shutdown is "      /*  Shutdown Cancelled Msg      */
                        "cancelled."                        ,
        }
    };



/* ******************************************************************************************** */
/* *                                                                                          * */
/* *    End of Resource Data                                                                  * */
/* *                                                                                          * */
/* ******************************************************************************************** */
